



python -m pip check
IF %ERRORLEVEL% NEQ 0 exit /B 1
cd tests && pytest --cov arrow -k "not parse_tz_name_zzz and not shift_kiritimati and not one_arg_dateparser_datetime"
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
